@@ -20,6 +20,14 @@ export interface BioLMAPIModel {
   tags: string[];
   docs_link: string | null;
   api_docs_link: string | null;
+  code_examples?: CodeExample[]; // Added for detail endpoint
+}
+
+export interface CodeExample {
+  action: string;
+  code: string;
+  description?: string;
+  [key: string]: any;
 }
 
 export interface BioLMModel {
@@ -32,6 +40,7 @@ export interface BioLMModel {
   companyModel?: boolean;
   actions?: string[]; // Derived from boolean flags (predictor, encoder, etc.)
   apiDocsLink?: string | null;
+  codeExamples?: CodeExample[]; // Added for code examples
   [key: string]: any; // Allow for additional metadata fields
 }
 
